==> derby-0.1.1.tgz: package/examples/todos/lib/todos/index.js <==
var get, listPath, ready, view, _ref;
_ref = require('derby').createApp(module), get = _ref.get, view = _ref.view, ready = _ref.ready;
listPath = '_todoList';
get('/', function(page) {
  return page.redirect('/derby');
});
get('/:group', function(page, model, _arg) {
  var group;
  group = _arg.group;
  return model.subscribe({
    _group: "groups." + group
  }, function() {
    model.setNull("groups." + group, {
      todos: {
        0: {
          id: 0,
          completed: true,
          text: 'This one is done already'
        },
        1: {
          id: 1,
          completed: false,
          text: 'Example todo'
        },
        2: {
          id: 2,
          completed: false,
          text: 'Another example'
        }
      },
      todoIds: [1, 2, 0],
      nextId: 3
    });
    model.set(listPath, model.arrayRef('_group.todos', '_group.todoIds'));
    return page.render();
  });
});
ready(function(model) {
  var todoList;
  todoList = $('#todos');
  todoList.sortable({
    handle: '.handle',
    axis: 'y',
    containment: '#dragbox',
    update: function(e, ui) {
      var domId, id, item, to;
      item = ui.item[0];
      domId = item.id;
      id = item.getAttribute('data-id');
      to = todoList.children().index(item);
      return model["with"]({
        ignore: domId
      }).move(listPath, {
        id: id
      }, to);
    }
  });
  model.on('set', '_todoList.*.completed', function(i, value) {
    if (value) {
      return model.move(listPath, i, -1);
    }
  });
  exports.add = function() {
    var i, list, text, todo, _len, _ref2;
    if (!(text = view.htmlEscape(model.get('_newTodo')))) {
      return;
    }
    model.set('_newTodo', '');
    _ref2 = list = model.get(listPath);
    for (i = 0, _len = _ref2.length; i < _len; i++) {
      todo = _ref2[i];
      if (todo.completed) {
        break;
      }
    }
    todo = {
      id: model.incr('_group.nextId'),
      completed: false,
      text: text
    };
    if (i === list.length) {
      return model.push(listPath, todo);
    } else {
      return model.insertBefore(listPath, i, todo);
    }
  };
  exports.del = function(e) {
    return model.remove(listPath, {
      id: e.target.getAttribute('data-id')
    });
  };
  model.set('_showReconnect', true);
  exports.connect = function() {
    model.set('_showReconnect', false);
    setTimeout((function() {
      return model.set('_showReconnect', true);
    }), 1000);
    return model.socket.socket.connect();
  };
  exports.reload = function() {
    return window.location.reload();
  };
  exports.shortcuts = function(e) {
    var code, command;
    if (!(e.metaKey || e.ctrlKey)) {
      return;
    }
    code = e.which;
    if (!(command = ((function() {
      switch (code) {
        case 66:
          return 'bold';
        case 73:
          return 'italic';
        case 32:
          return 'removeFormat';
        case 220:
          return 'removeFormat';
        default:
          return null;
      }
    })()))) {
      return;
    }
    document.execCommand(command, false, null);
    if (e.preventDefault) {
      e.preventDefault();
    }
    return false;
  };
  document.execCommand('useCSS', false, true);
  return document.execCommand('styleWithCSS', false, false);
});

==> derby-0.1.2.tgz: package/examples/todos/lib/todos/index.js <==
var get, listPath, ready, view, _ref;
_ref = require('derby').createApp(module), get = _ref.get, view = _ref.view, ready = _ref.ready;
listPath = '_todoList';
get('/', function(page) {
  return page.redirect('/derby');
});
get('/:group', function(page, model, _arg) {
  var group;
  group = _arg.group;
  return model.subscribe({
    _group: "groups." + group
  }, function() {
    model.setNull("groups." + group, {
      todos: {
        0: {
          id: 0,
          completed: true,
          text: 'This one is done already'
        },
        1: {
          id: 1,
          completed: false,
          text: 'Example todo'
        },
        2: {
          id: 2,
          completed: false,
          text: 'Another example'
        }
      },
      todoIds: [1, 2, 0],
      nextId: 3
    });
    model.set(listPath, model.arrayRef('_group.todos', '_group.todoIds'));
    return page.render();
  });
});
ready(function(model) {
  var todoList;
  todoList = $('#todos');
  todoList.sortable({
    handle: '.handle',
    axis: 'y',
    containment: '#dragbox',
    update: function(e, ui) {
      var domId, id, item, to;
      item = ui.item[0];
      domId = item.id;
      id = item.getAttribute('data-id');
      to = todoList.children().index(item);
      return model["with"]({
        ignore: domId
      }).move(listPath, {
        id: id
      }, to);
    }
  });
  model.on('set', '_todoList.*.completed', function(i, value, isLocal) {
    if (value && isLocal) {
      return model.move(listPath, i, -1);
    }
  });
  exports.add = function() {
    var i, list, text, todo, _len, _ref2;
    if (!(text = view.htmlEscape(model.get('_newTodo')))) {
      return;
    }
    model.set('_newTodo', '');
    _ref2 = list = model.get(listPath);
    for (i = 0, _len = _ref2.length; i < _len; i++) {
      todo = _ref2[i];
      if (todo.completed) {
        break;
      }
    }
    todo = {
      id: model.incr('_group.nextId'),
      completed: false,
      text: text
    };
    if (i === list.length) {
      return model.push(listPath, todo);
    } else {
      return model.insertBefore(listPath, i, todo);
    }
  };
  exports.del = function(e) {
    return model.remove(listPath, {
      id: e.target.getAttribute('data-id')
    });
  };
  model.set('_showReconnect', true);
  exports.connect = function() {
    model.set('_showReconnect', false);
    setTimeout((function() {
      return model.set('_showReconnect', true);
    }), 1000);
    return model.socket.socket.connect();
  };
  exports.reload = function() {
    return window.location.reload();
  };
  exports.shortcuts = function(e) {
    var code, command;
    if (!(e.metaKey || e.ctrlKey)) {
      return;
    }
    code = e.which;
    if (!(command = ((function() {
      switch (code) {
        case 66:
          return 'bold';
        case 73:
          return 'italic';
        case 32:
          return 'removeFormat';
        case 220:
          return 'removeFormat';
        default:
          return null;
      }
    })()))) {
      return;
    }
    document.execCommand(command, false, null);
    if (e.preventDefault) {
      e.preventDefault();
    }
    return false;
  };
  document.execCommand('useCSS', false, true);
  return document.execCommand('styleWithCSS', false, false);
});
